sqlobject.tests.test_reparent_sqlmeta module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_reparent_sqlmeta module

class `sqlobject.tests.test_reparent_sqlmeta.` `Reparented1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `dummy`
  `j` = reparented1
  `q` = reparented1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_reparent_sqlmeta.Reparented1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'reparented1'

class `sqlobject.tests.test_reparent_sqlmeta.` `Reparented2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `dummy`
  `j` = reparented2
  `q` = reparented2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    classmethod `setClass`(soClass)
    `soClass`

      alias of `sqlobject.tests.test_reparent_sqlmeta.Reparented2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'reparented2'
    `worked` = True

`sqlobject.tests.test_reparent_sqlmeta.` `test_reparented`()